package com.jetlore.sdk.common;



import android.util.Log;
import com.jetlore.sdk.http.AsyncHttpResponseHandler;
import com.jetlore.sdk.http.RequestHandle;


import org.apache.http.Header;

/**
 * Class that triggers HTTP GET calls on {@link Event#fire()}
 */
public abstract class GetEvent extends Event {

    protected GetEvent(EventBuilder<? extends GetEvent> builder) {
        super(builder);
    }

    public void fire() {
        final String url = toURL();

        Log.d(TAG, String.format("%s request: GET %s", this.getClass().getSimpleName(), url));

        new Request() {
            @Override
            protected RequestHandle send(AsyncHttpResponseHandler responseHandler) {
                return httpClient.get(url, responseHandler);
            }

            @Override
            public void onSuccess(int statusCode, Header[] headers, byte[] responseBody) {
                Log.d(TAG, String.format("GET request to %s finished with statusCode %d", url, statusCode));
                GetEvent.this.onSuccess(statusCode, headers, responseBody);
            }

            @Override
            public void onFailure(int statusCode, Header[] headers, byte[] responseBody, Throwable error) {
                Log.d(TAG, String.format("GET request to %s finished with statusCode %d and error %s",
                        url, statusCode, error));
                GetEvent.this.onFailure(statusCode, headers, responseBody, error);
            }
        }.run();
    }

}
