package com.jetlore.sdk.common;

import org.apache.http.Header;

import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public final class Util {
    private static final String UTF_8 = "UTF-8";

    private Util() {}


    private static final Pattern charsetPattern = Pattern.compile("(?i)\\bcharset=\\s*\"?([^\\s;\"]*)");

    public static boolean isNullOrEmpty(String s) {
        return s == null || s.trim().equals("");
    }

    public static String URLEncode(String s) {
        try {
            return URLEncoder.encode(s, UTF_8);
        } catch (UnsupportedEncodingException ex) { // can't happen
            throw new RuntimeException(String.format("Util.URLEncode(%s) thrown UnsupportedEncodingException", s), ex);
        }
    }


    public static String getCharsetFromContentType(Header[] headers) {

        String contentType = null;
        if (null != headers) {
            for (Header header : headers) {
                if (header.getName().equalsIgnoreCase("Content-Type")) {
                    contentType = header.getValue();
                    break;
                }
            }
        }


        if (contentType == null)
            return "UTF-8";

        Matcher m = charsetPattern.matcher(contentType);
        if (m.find()) {
            return m.group(1).trim().toUpperCase();
        }
        return "UTF-8";
    }
}
