package com.jetlore.sdk.ranking;

import android.util.Log;

import com.jetlore.sdk.http.AsyncHttpClient;
import com.jetlore.sdk.common.InvalidUseException;
import com.jetlore.sdk.common.Util;
import com.jetlore.sdk.ranking.callback.GetLayoutCallback;
import com.jetlore.sdk.ranking.layout.LayoutConfiguration;

import org.apache.http.Header;
import org.json.JSONException;
import org.json.JSONObject;

import java.io.UnsupportedEncodingException;
import java.util.Map;

public class GetLayoutEvent extends RankingGetEvent {

    private String clientHash;
    private String layout;

    private GetLayoutCallback callback;

    private GetLayoutEvent(Builder builder) {
        super(builder);
        this.clientHash = builder.clientHash;

        if (builder.layoutName != null) {
            this.layout = builder.layoutName;
        } else if (null != builder.layoutConfiguration) {
            try {
                this.layout = builder.layoutConfiguration.toJSONObject().toString();
            } catch (JSONException ex) {
                Log.e(TAG, "Failed to convert layout configuration object to JSON", ex);
                callback.onFailure("API Call canceled: Failed to convert layout configuration object to JSON", ex);
            }
        }

        this.callback = builder.callback;
    }

    protected Map<String, String> getQueryParams() {
        return null;
    }

    protected String generateMainGetRequestURL() {
        StringBuilder sb = new StringBuilder();
        sb.append(String.format("%s/layouts/layout.json?cid=%s&jl_ctx=mobile&layout=%s",
                apiUrl,
                Util.URLEncode(clientHash),
                Util.URLEncode(layout)
        ));

        if (null != userId) {
            sb.append(String.format("&id=%s", Util.URLEncode(userId)));
        }

        return sb.toString();
    }

    @Override
    protected void onSuccess(int statusCode, Header[] headers, byte[] responseBody)  {
        try {
            JSONObject json = new JSONObject(new String(responseBody, Util.getCharsetFromContentType(headers)));
            callback.onSuccess(Layout.fromJSONObject(json));
        } catch (UnsupportedEncodingException ex) {
            Log.e(TAG, "Failed to parse response from server unsupported content type", ex);
            callback.onFailure("Failed to parse response from server unsupported content type", ex);
        } catch (JSONException ex) {
            Log.e(TAG,"Failed to parse JSON response from server", ex);
            callback.onFailure("Failed to parse JSON response from server", ex);
        } catch (Exception ex) {
            Log.e(TAG,"Failed to parse JSON unexpected result", ex);
            callback.onFailure("Failed to parse JSON unexpected result", ex);
        }

    }

    @Override
    protected void onFailure(int statusCode, Header[] headers, byte[] responseBody, Throwable error) {
        Log.e(TAG, "Failed to perform request. HTTP status code %n", error);
        callback.onFailure(String.format("Failed to perform request. HTTP status code %n", statusCode), error);
    }

    static class Builder extends RankingEventBuilder<GetLayoutEvent> {

        private String clientHash;
        private String layoutName;
        private LayoutConfiguration layoutConfiguration;
        private GetLayoutCallback callback;

        public Builder(String userId, String apiUrl,  String clientHash, AsyncHttpClient httpClient) {
            super(userId, apiUrl, null, httpClient);
            this.clientHash = clientHash;
        }

        public Builder layoutName(String layoutName) {
            this.layoutName = layoutName;
            return this;
        }

        public Builder layout(LayoutConfiguration layoutConfiguration) {
            this.layoutConfiguration = layoutConfiguration;
            return this;
        }

        public Builder callback(GetLayoutCallback callback) {
            this.callback = callback;
            return this;
        }

        @Override
        public GetLayoutEvent build() {

            if (null == layoutName && null == layoutConfiguration) {
                throw new InvalidUseException("One of parameters either LayoutName or Layout must be provided");
            }
            if (null == callback) {
                throw new InvalidUseException("Callback is required parameter");
            }

            return new GetLayoutEvent(this);
        }
    }
}
