package com.jetlore.sdk.ranking;

import org.json.JSONArray;
import org.json.JSONObject;

import java.io.Serializable;
import java.util.LinkedList;
import java.util.List;

/**
 * Layout is a combination of sections. Each section could be product {@link ProductSection} section or promotion {@link PromotionSection} section
 */
public class Layout implements Serializable {

    private List<Section> sections;

    /**
     * Gets list of layout sections
     *
     * @return list of layout sections
     */
    public List<Section> getSections() {
        return sections;
    }

    static Layout fromJSONObject(JSONObject obj) {
        Layout layout = new Layout();
        List<Section> parsedSections = null;
        JSONArray sections;

        if (null != (sections = obj.optJSONArray("sections"))){
            parsedSections = new LinkedList<Section>();
            for (int i = 0; i < sections.length(); i++) {
                JSONObject section = sections.optJSONObject(i);
                if (null != section) {
                    parsedSections.add(Section.fromJSONObject(section));
                }
            }
        } else {
            throw new IllegalArgumentException("Layout object does not contains 'sections'");
        }
        layout.sections = parsedSections;

        return layout;
    }
}
