package com.jetlore.sdk.ranking;

import org.json.JSONArray;
import org.json.JSONObject;

import java.util.LinkedList;
import java.util.List;

/**
 * Represents Layout product section
 */
public class ProductSection extends Section {

    private List<Product> products;

    /**
     * Gets list of featured products
     *
     * @return list of featured products
     */
    public List<Product> getProducts() {
        return products;
    }

    /**
     * This method will trigger appropriate visit method {@link SectionVisitor#visit(ProductSection)}
     *
     * @param visitor object
     */
    @Override
    public void handle(SectionVisitor visitor) {
        visitor.visit(this);
    }

    static Section fromJSONObject(JSONObject obj) {
        ProductSection layoutSection = new ProductSection();

        List<Product> parsedProducts = null;
        JSONArray products;
        if (null != (products = obj.optJSONArray("products"))){
            parsedProducts = new LinkedList<Product>();
            for (int i = 0; i < products.length(); i++) {
                JSONObject product = products.optJSONObject(i);
                if (null != product) {
                    parsedProducts.add(Product.fromJSONObject(product));
                }
            }
        }
        layoutSection.products = parsedProducts;

        return layoutSection;
    }

}
