package com.jetlore.sdk.ranking;

import org.json.JSONArray;
import org.json.JSONObject;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

/**
 * Object that represents single Promotion object from Promotion Section {@link PromotionSection#getPromos()}
 */
public class PromotionInfo implements Serializable {

    private String id;
    private String title;
    private String url;
    private String img;
    private String mobileImg;
    private List<Product> featuredProducts;

    private Map<String, String> fields = new HashMap<String, String>();

    /**
     * Get promotion id
     *
     * @return  promotion id
     */
    public String getId() {
        return id;
    }

    /**
     * Get Title
     *
     * @return tile identifier
     */
    public String getTitle() {
        return title;
    }

    /**
     * Get Promotion URL
     *
     * @return URL to redirect user on this promotion
     */
    public String getUrl() {
        return url;
    }

    /**
     * Gets Promotion image URL. Lower resolution (Desktop resolution)
     *
     * @return - url on image. Null in case if we don't have it
     */
    public String getImg() {
        return img;
    }

    /**
     * Gets Promotion image URL. High resolution (Mobile resolution)
     *
     * @return - url on image. Null in case if we don't have it
     */
    public String getMobileImg() {
        return mobileImg;
    }

    public List<Product> getFeaturedProducts() {
        return featuredProducts;
    }
    /**
     * Gets additional fields
     *
     * Normally Mobile SDK parses response in convenient methods
     * If you will be using outdated SDK you will have access to unexpected fields in here.
     *
     * @return map of fields (key, value)
     */
    public Map<String, String> getFields() {
        return fields;
    }

    static PromotionInfo fromJSONObject(JSONObject obj) {
        PromotionInfo promotion = new PromotionInfo();

        promotion.id = obj.optString("id", null);
        promotion.title = obj.optString("title");
        promotion.url = obj.optString("url", null);
        promotion.img = obj.optString("img", null);
        promotion.mobileImg = obj.optString("mobile_img", null);

        List<Product> parsedProducts = null;
        JSONArray products;

        if (null != (products = obj.optJSONArray("featured_products"))){
            parsedProducts = new LinkedList<Product>();
            for (int i = 0; i < products.length(); i++) {
                JSONObject product = products.optJSONObject(i);
                if (null != product) {
                    parsedProducts.add(Product.fromJSONObject(product));
                }
            }
        }
        promotion.featuredProducts = parsedProducts;

        Iterator<String> keysIterator = obj.keys();
        while(keysIterator.hasNext()) {
            String key = keysIterator.next();
            Object value = obj.opt(key);

            if (value instanceof String) {
                promotion.fields.put(key, (String) value);
            } else if (value != null) {
                promotion.fields.put(key, String.valueOf(value));
            } else {
                promotion.fields.put(key, null);
            }

        }

        return promotion;
    }

}
