package com.jetlore.sdk.ranking;

import org.json.JSONArray;
import org.json.JSONObject;

import java.util.LinkedList;
import java.util.List;

/**
 * Represents Layout promotion section
 */
public class PromotionSection extends Section {

    private List<PromotionInfo> promos;

    /**
     * List of promotions selected for this section (by Jetlore API)
     *
     * @return list of promotions
     */
    public List<PromotionInfo> getPromos() {
        return promos;
    }

    /**
     * This method will trigger appropriate visit method {@link SectionVisitor#visit(PromotionSection)}
     *
     * @param visitor object
     */
    @Override
    public void handle(SectionVisitor visitor) {
        visitor.visit(this);
    }

    static Section fromJSONObject(JSONObject obj) {

        PromotionSection layoutSection = new PromotionSection();


        List<PromotionInfo> parsedPromtions = null;
        JSONArray promotions;
        if (null != (promotions = obj.optJSONArray("promos"))){
            parsedPromtions = new LinkedList<PromotionInfo>();
            for (int i = 0; i < promotions.length(); i++) {
                JSONObject promotion = promotions.optJSONObject(i);
                if (null != promotion) {
                    parsedPromtions.add(PromotionInfo.fromJSONObject(promotion));
                }
            }
        }
        layoutSection.promos = parsedPromtions;

        return layoutSection;
    }
}
