package com.jetlore.sdk.ranking;


import com.jetlore.sdk.tracking.ActionContext;

import java.util.LinkedList;
import java.util.List;

/**
 * Ranking action context
 *
 * This object holds additional field <b>productIds</b> in addition to standard {@link ActionContext} fields
 *
 * If you specify them you will receive similar products in ranking recommendations
 *
 */
public class RankContext extends ActionContext {

    private List<String> productIds = new LinkedList<String>();

    /**
     * Constructs context without feed identification
     */
    public RankContext() {
        super();
    }

    /**
     * Constructs object with feed identification
     *
     * @param feedId is string identification of client feed
     */
    public RankContext(String feedId) {
        super(feedId);
    }

    /**
     * Add single product id. This id is used for similarity selection
     *
     * @param productId  product identification  (SKU number)
     */
    public void addProductId(String productId) {
        this.productIds.add(productId);
    }

    /**
     * Add multiple  product ids. This id is used for similarity selection
     *
     * @param productIds list of product identifications  (SKU numbers)
     */
    public void addProductIds(List<String> productIds) {
        this.productIds.addAll(productIds);
    }

    /**
     * Gets product ids that will be used similarity
     *
     * @return list of product ids (SKU number)
     */
    public List<String> getProductIds(){
        return this.productIds;
    }
}
