package com.jetlore.sdk.ranking;

/**
 * Section visitor. Layout sections list {@link Layout#getSections()} contains ordered list of sections
 *
 * Each section could be either {@link PromotionSection} or {@link ProductSection}.
 * This interface is created to be used in {@link Section#handle(SectionVisitor)}.
 * Depending on a type of Section appropriate visit method will be called
 *
 */
public interface SectionVisitor {

    /**
     * Invoked if {@link Section} has {@link PromotionSection} type
     *
     * @param section section object
     */
    void visit(PromotionSection section);

    /**
     * Invoked if {@link Section} has {@link ProductSection} type
     *
     * @param section section object
     */
    void visit(ProductSection section);

}
