package com.jetlore.sdk.ranking;


import com.jetlore.sdk.tracking.ActionContext;

import java.util.List;

/**
 * Sort Products action context
 *
 * This object holds additional field <b>productIds</b> or <b>filter</b>
 *
 * If you specify them you will receive similar products in recommendations
 *
 */
public class SortProductsContext extends ActionContext {

    List<String> productIds;
    Pagination pagination;
    Filter filter;

    /**
     * Constructs SortProductsContext based on predefined list of productIds and pagination
     *
     * @param productIds list of product ids
     * @param pagination pagination object is required and cant be null
     */
    public SortProductsContext(List<String> productIds, Pagination pagination) {
        this.productIds = productIds;
        this.pagination = pagination;
    }

    /**
     * Constructs SortProductsContext based on generic filter and pagination
     *
     * Please use {@link com.jetlore.sdk.ranking.Filter.Builder} to initialize/create filter
     *
     * @param filter generic filter
     * @param pagination pagination object
     */
    public SortProductsContext(Filter filter, Pagination pagination) {
        this.filter = filter;
        this.pagination = pagination;
    }

    /**
     * Represents pagination in request
     */
    public static class Pagination {
        int itemsPerPage;
        int pageNo;

        public static final int MAX_ITEMS_PER_PAGE = 1000;

        /**
         * Construct pagination object
         *
         * @param pageNo requested page. <b>Fist page is 1</b>
         * @param itemPerPage items per page cont to return. Should be less then {@link Pagination#MAX_ITEMS_PER_PAGE}
         */
        public Pagination(int pageNo, int itemPerPage) {
            this.itemsPerPage = itemPerPage;
            this.pageNo = pageNo;
        }
    }
}
