package com.jetlore.sdk.ranking.layout;

import com.jetlore.sdk.common.InvalidUseException;

import org.json.JSONException;
import org.json.JSONObject;


public class FeaturedProductsOptions {

    private int promotionIndex = Integer.MAX_VALUE;

    private int limit;
    private String tileName;
    private Boolean showPromoTile = true;

    protected FeaturedProductsOptions(Builder builder) {
        this(builder.promotionIndex,
             builder.limit,
             builder.tile,
             builder.showPromoTile);
    }

    /**
     * Configures how many products to fetsh per promotion at position {@link #promotionIndex}
     *
     * @param promotionIndex - specified product configuration is only relevant for promotion at this position (inside section)
     * @param limit limit of products
     * @param tile product tile id
     */
    public FeaturedProductsOptions(int promotionIndex, int limit, String tile) {
        if (promotionIndex <= 0) {
            throw new IllegalArgumentException("Value of promotionIndex must be greater then 0");
        }
        if (limit <= 0) {
            throw new InvalidUseException("Value of " + limit + " must be greater then 0");
        }

        this.limit = limit;
        this.tileName = tile;
        this.promotionIndex = promotionIndex;
    }

    public FeaturedProductsOptions(int promotionIndex, int limit, String tile, Boolean showPromoTile) {
        this(promotionIndex, limit, tile);
        this.showPromoTile = showPromoTile;
    }

    JSONObject toJSONObject() throws JSONException {
        JSONObject obj = new JSONObject();

        obj.put("featured_products", limit);
        obj.putOpt("tile", tileName);
        obj.putOpt("promo_tile", showPromoTile);

        return obj;
    }

    protected int getPromotionIndex() {
        return promotionIndex;
    }

    // ================== Builder ==================
    public static class Builder {

        private int promotionIndex;

        private int limit;
        private String tile;
        private Boolean showPromoTile = true;

        private PromotionSectionConfiguration.Builder parentBuilder;

        protected Builder(PromotionSectionConfiguration.Builder parentBuilder) {
            this.parentBuilder = parentBuilder;
        }

        public Builder tile(String tileName){
            this.tile = tileName;
            return this;
        }

        public Builder showPromoTile(Boolean showPromoTile){
            this.showPromoTile = showPromoTile;
            return this;
        }

        public Builder limit(int limit){
            this.limit = limit;
            return this;
        }

        public Builder promotionIndex(int promotionIndex){
            this.promotionIndex = promotionIndex;
            return this;
        }

        public FeaturedProductsOptions build() {
           return new FeaturedProductsOptions(this);
        }

        public PromotionSectionConfiguration.Builder buildAddAndGoUp() {
            parentBuilder.addFeaturedProductsOption(build());
            return parentBuilder;
        }
    }
}