package com.jetlore.sdk.ranking.layout;

import android.support.annotation.NonNull;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.LinkedList;
import java.util.List;

public class LayoutConfiguration {

    List<SectionConfiguration> sections;

    protected LayoutConfiguration(Builder builder) {
        this(builder.sections);
    }

    public LayoutConfiguration(@NonNull List<SectionConfiguration> sections) {
        this.sections = sections;
    }

    public JSONObject toJSONObject() throws JSONException {
        JSONObject obj = new JSONObject();
        JSONArray jsonSections = new JSONArray();

        if (null != sections) {
            for (SectionConfiguration section : sections) {
                jsonSections.put(section.toJSONObject());
            }
        }
        obj.put("sections", jsonSections);
        return obj;
    }

    void addConfigurationSection(SectionConfiguration section){
        sections.add(section);
    }

    // ================== Builder ==================
    public static class Builder {

        private List<SectionConfiguration> sections = new LinkedList<SectionConfiguration>();

        public Builder sections(List<SectionConfiguration> sections) {
            this.sections = sections;
            return this;
        }

        public Builder section(SectionConfiguration section) {
            this.sections.add(section);
            return this;
        }

        public PromotionSectionConfiguration.Builder promotionConfigurationSectionBuilder() {
            return new PromotionSectionConfiguration.Builder(this);
        }

        public ProductSectionConfiguration.Builder productConfigurationSectionBuilder() {
            return new ProductSectionConfiguration.Builder(this);
        }

        public LayoutConfiguration build() {
            return new LayoutConfiguration(this);
        }
    }
}
