package com.jetlore.sdk.ranking.layout;

import android.support.annotation.NonNull;

import com.jetlore.sdk.common.InvalidUseException;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

public class ProductSectionConfiguration extends SectionConfiguration {

    private String tileName;
    private String filter;

    private List<Integer> linkedSections;

    protected ProductSectionConfiguration(Builder builder){
        this(builder.limit,
                builder.customFields,
                builder.tileName,
                builder.filter,
                builder.linkedSections);
    }

    public ProductSectionConfiguration(int limit,
                                       @NonNull Map<String, String> customFields,
                                       @NonNull String tileName,
                                       String filter,
                                       List<Integer> linkedSections) {
        super(SectionType.PRODUCT, limit, customFields);

        if (tileName == null) {
            throw new InvalidUseException("Value of " + tileName + " must be provided");
        }
        this.tileName = tileName;
        this.filter = filter;
        this.linkedSections = linkedSections;
    }



    JSONObject toJSON(JSONObject obj) throws JSONException {

        obj.put("tile", tileName);
        obj.putOpt("filter", filter);

        if (null != linkedSections) {
            JSONArray promoSectionLink = new JSONArray();
            for (Integer link : linkedSections) {
                promoSectionLink.put(link);
            }

            obj.put("linked_sections", linkedSections);
        }

        return obj;
    }

    // ================== Builder ==================
    public static class Builder {
        private int limit;
        private Map<String, String> customFields = new HashMap<String, String>();

        private String tileName;
        private String filter;
        private List<Integer> linkedSections = new LinkedList<Integer>();

        LayoutConfiguration.Builder parentBuilder;

        protected Builder(LayoutConfiguration.Builder parentBuilder) {
            this.parentBuilder = parentBuilder;
        }

        public Builder tileName(String tileName){
            this.tileName = tileName;
            return this;
        }

        public Builder filter(String filter){
            this.filter = filter;
            return this;
        }

        public Builder linkedSections(List<Integer> linkedSections){
            this.linkedSections = linkedSections;
            return this;
        }

        public Builder linkedSection(Integer linkedSection){
            this.linkedSections.add(linkedSection);
            return this;
        }

        public Builder limit(int limit) {
            this.limit = limit;
            return this;
        }

        public Builder customField(String name, String value) {
            customFields.put(name, value);
            return this;
        }

        public Builder customFields(Map<String, String> customFields) {
            this.customFields.putAll(customFields);
            return this;
        }

        public ProductSectionConfiguration build() {
            return new ProductSectionConfiguration(this);
        }

        public LayoutConfiguration.Builder buildAddAndGoUp() {
            parentBuilder.section(build());
            return parentBuilder;
        }
    }

}
