package com.jetlore.sdk.ranking.layout;

import android.support.annotation.NonNull;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.HashMap;
import java.util.Map;

public abstract class SectionConfiguration {

    SectionType type;
    int limit;

    private Map<String, String> customFields = new HashMap<String, String>();

    public SectionConfiguration(@NonNull SectionType type, int limit, Map<String, String> customFields) {
        if (limit <= 0) {
            throw new IllegalArgumentException("Value of " + limit + " must be greater then 0");
        }
        if (type == null) {
            throw new IllegalArgumentException("Value of " + type + " must be provided");
        }

        this.type = type;
        this.limit = limit;
        this.customFields = customFields;
    }

    abstract JSONObject toJSON(JSONObject obj) throws JSONException;

    public JSONObject toJSONObject() throws JSONException {
        JSONObject obj = new JSONObject();

        obj.put("type", type.getJsonTypeString());
        obj.put("limit", limit);

        if (null != customFields && !customFields.isEmpty()) {
            for (Map.Entry<String, String> customFiled : customFields.entrySet()) {
                obj.put(customFiled.getKey(), customFiled.getValue());
            }
        }

        return toJSON(obj);
    }

    public SectionType getType() {
        return type;
    }

    public int getLimit() {
        return limit;
    }


    public void addCustomField(String name, String value){
        customFields.put(name, value);
    }

    public void addCustomFields(Map<String, String> parameters){
        customFields.putAll(parameters);
    }
}
