package com.jetlore.sdk.tracking;


import com.jetlore.sdk.http.AsyncHttpClient;
import com.jetlore.sdk.common.InvalidUseException;
import com.jetlore.sdk.common.Util;

import java.util.HashMap;
import java.util.Map;

class GenericEvent extends TrackingEvent {

    private String action;

    private Map<String, String> parameters = new HashMap<String, String>();

    private GenericEvent(Builder builder) {
        super(builder);
        this.parameters = builder.parameters;
        this.action = builder.action;
    }

    protected Map<String, String> getQueryParams() {
        return parameters;
    }

    protected String getAction(){
        return action;
    }

    static class Builder extends TrackingEventBuilder<GenericEvent> {

        private String action;
        private Map<String, String> parameters = new HashMap<String, String>();

        Builder(String userId, String action, String apiUrl, String accessToken, AsyncHttpClient httpClient) {
            super(userId, apiUrl, accessToken, httpClient);
            this.action = action;
        }

        public Builder withParameter(String name, String value) {
            parameters.put(name, value);
            return this;
        }

        @Override
        public GenericEvent build() {
            if (Util.isNullOrEmpty(action)) {
                throw new InvalidUseException("action is required");
            }
            return new GenericEvent(this);
        }
    }
}
