package com.jetlore.sdk.tracking;

import com.jetlore.sdk.http.AsyncHttpClient;

import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

class SearchEvent extends TrackingEvent {

    private List<String> texts;

    private SearchEvent(Builder builder) {
        super(builder);
        this.texts = builder.texts;
    }

    protected Map<String, String> getQueryParams() {
        Map<String, String> parametersMap = new HashMap<String, String>();
        parametersMap.put("data", getEncodedTestData());
        return parametersMap;
    }

    protected String getEncodedTestData() {
        StringBuilder sb  = new StringBuilder();
        sb.append("[");
        if (null != texts && !texts.isEmpty()) {
            Iterator<String> productItr = texts.iterator();
            sb.append("{\"text\": \"").append(productItr.next()).append("\"}");
            while (productItr.hasNext()) {
                sb.append(",{\"text\": \"").append(productItr.next()).append("\"}");
            }
        }
        sb.append("]");

        return sb.toString();
    }

    protected String getAction() {
        return "search";
    }

    static class Builder extends TrackingEventBuilder<SearchEvent> {

        private List<String> texts = new LinkedList<String>();

        public Builder(String userId, String apiUrl, String accessToken, AsyncHttpClient httpClient) {
            super(userId, apiUrl, accessToken, httpClient);
        }

        public Builder searchText(String text) {
            this.texts.add(text);
            return this;
        }

        @Override
        public SearchEvent build() {
            return new SearchEvent(this);
        }

    }
}
