package com.jetlore.sdk.tracking;


import com.jetlore.sdk.http.AsyncHttpClient;
import com.jetlore.sdk.common.GetEvent;
import com.jetlore.sdk.common.InvalidUseException;
import com.jetlore.sdk.common.Util;

import org.json.JSONException;

import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;

abstract class TrackingEvent extends GetEvent {

    protected String accessToken;

    protected abstract String getAction();

    protected TrackingEvent(TrackingEventBuilder<? extends TrackingEvent> builder) {
        super(builder);
        this.accessToken = builder.accessToken;
    }

    protected String generateMainGetRequestURL() {
        StringBuilder sb = new StringBuilder();
        sb.append(String.format("%s/track/%s/%s?access_token=%s&jl_ctx=mobile",
                apiUrl,
                Util.URLEncode(getAction()),
                Util.URLEncode(userId),
                Util.URLEncode(accessToken)
        ));

        return sb.toString();
    }

    static abstract class TrackingEventBuilder<T> extends GetEvent.EventBuilder<T> {

        private String accessToken;

        protected TrackingEventBuilder(String  userId, String apiUrl, String accessToken, AsyncHttpClient httpClient) {
            super(userId, apiUrl, httpClient);
            this.accessToken = accessToken;
        }

        public abstract T build();
    }

    static abstract class TrackingProductEventBuilder<T> extends TrackingEventBuilder<T> {

        protected List<ProductContext> products = new LinkedList<>();

        TrackingProductEventBuilder(String  userId, String apiUrl, String accessToken, AsyncHttpClient httpClient) {
            super(userId, apiUrl, accessToken, httpClient);
        }

        public TrackingProductEventBuilder<T> product(ProductContext product) {
            if (null != product) {
                validate(product);
                this.products.add(product);
            }
            return this;
        }

        public TrackingProductEventBuilder<T> products(List<ProductContext> products) {
            if (null != products) {
                for (ProductContext product : products) {
                    validate(product);
                }
                this.products.addAll(products);
            }
            return this;
        }

        void validate(ProductContext product){
            if (Util.isNullOrEmpty(product.getProductId())) {
                throw new InvalidUseException("Product id is required");
            }
            if (product.getCount() <= 0) {
                throw new InvalidUseException("Product count <= 0");
            }
        }

        public abstract T build();
    }


    static String toJSONArray(List<ProductContext> products) throws JSONException {
        StringBuilder sb  = new StringBuilder();
        sb.append("[");
        if (null != products && !products.isEmpty()) {
            Iterator<ProductContext> productItr = products.iterator();
            sb.append(productItr.next().toJSONString());
            while (productItr.hasNext()) {
                sb.append(",").append(productItr.next().toJSONString());
            }
        }
        sb.append("]");

        return sb.toString();
    }
}
