package com.jetlore.sdk.tracking;


import android.util.Log;

import com.jetlore.sdk.http.AsyncHttpClient;
import com.jetlore.sdk.common.Util;

import org.json.JSONException;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

class ViewEvent extends TrackingEvent {

    private List<ProductContext> products;
    private String  campaignId;

    private ViewEvent(Builder builder) {
        super(builder);

        this.products = builder.products;
        this.campaignId = builder.campaignId;
    }

    protected Map<String, String> getQueryParams() {
        Map<String, String> parametersMap = new HashMap<String, String>();
        try {
            if (!Util.isNullOrEmpty(campaignId)) {
                parametersMap.put("cmpn", campaignId);
            }
            parametersMap.put("data", toJSONArray(products));
        } catch (JSONException ex) {
            Log.e(TAG, String.format("ViewEvent failed to represent products as JSON"));
        }
        return parametersMap;
    }

    protected String getAction(){
        return "click";
    }

    static class Builder extends TrackingProductEventBuilder<ViewEvent> {

        private String campaignId;

        public Builder(String userId, String apiUrl, String accessToken, AsyncHttpClient httpClient) {
            super(userId, apiUrl, accessToken, httpClient);
        }

        public Builder product(String productId) {
            product(new ProductContext(productId));
            return this;
        }

        public Builder campaign(String campaignId) {
            this.campaignId = campaignId;
            return this;
        }

        @Override
        public ViewEvent build(){

            // this is backward compatibility
            if (null != campaignId && campaignId.equals(ActionTracker.NO_CAMPAIGN)) {
                campaignId = null;
            }

            return new ViewEvent(this);
        }

    }

}
